@@ -92,6 +92,32 @@ schemes = {
             'links': lambda x: list(itertools.chain(*[l.get('addresses') for l in x.get('social', [])])),
         },
     },
+    'Yandex Music API': {
+        'flags': ['invocationInfo', 'req-id"'],
+        'regex': r'^(.+)$',
+        'extract_json': True,
+        'transforms': [
+            json.loads,
+            lambda x: x.get('result', {}),
+            json.dumps,
+        ],
+        'fields': {
+            'username': lambda x: x.get('login'),
+            'yandex_uid': lambda x: x.get('uid'),
+            'yandex_public_id': lambda x: x.get('publicId'),
+            'fullname': lambda x: x.get('fullName'),
+            'links': lambda x: x.get('socialProfiles'),
+            'is_verified': lambda x: x.get('verified'),
+            'has_tracks': lambda x: x.get('statistics', {}).get('hasTracks'),
+            'liked_users': lambda x: x.get('statistics', {}).get('likedUsers'),
+            'liked_by_users': lambda x: x.get('statistics', {}).get('likedByUsers'),
+            'liked_artists': lambda x: x.get('statistics', {}).get('likedArtists'),
+            'liked_albums': lambda x: x.get('statistics', {}).get('likedAlbums'),
+            'ugc_tracks_count': lambda x: x.get('statistics', {}).get('ugcTracks'),
+            'is_private_statistics': lambda x: x.get('statistics') == 'private',
+            'is_private_social_profiles': lambda x: x.get('socialProfiles') == 'private',
+        },
+    },
     'Yandex Realty offer': {
         'flags': ['realty.yandex.ru/offer'],
         'regex': r'({"routing":{"locationBeforeTransitions.+?});',
@@ -288,6 +314,17 @@ schemes = {
             'external_url': lambda x: x['entry_data']['ProfilePage'][0]['graphql']['user'].get('external_url'),
         }
     },
+    'Spotify API': {
+        'flags': ['"uri": "spotify:user:'],
+        'regex': r'^({[\S\s]+?})$',
+        'extract_json': True,
+        'fields': {
+            'username': lambda x: x.get('name'),
+            'follower_count': lambda x: x.get('followers_count'),
+            'following_count': lambda x: x.get('following_count'),
+            'image': lambda x: x.get('image_url', ''),
+        }
+    },
     'EyeEm': {
         'flags': ['window.__APOLLO_STATE__', 'cdn.eyeem.com/thumb'],
         'regex': r'__APOLLO_STATE__ = ({.+?});\n',
@@ -337,7 +374,12 @@ schemes = {
     },
     'Habrahabr': {
         'flags': ['habracdn.net'],
-        'regex': r'<div class="page-header page-header_full js-user_(?P<uid>\d+)">[\s\S]*?/users/(?P<username>.*?)/([\s\S]+?<img src="(?P<image>//habrastorage\.org/getpro/habr/avatars.+?)")?',
+        'bs': True,
+        'fields': {
+            'uid': lambda x: x.find('div', {'class': 'user-info__stats'}).parent.attrs['class'][-1].split('_')[-1],
+            'username': lambda x: x.find('a', {'class': 'media-obj__image'}).get('href').split('/')[-2],
+            'image': lambda x: 'http:' + x.find('div', {'class': 'user-info__stats'}).find('img').get('src'),
+        },
     },
     # unactual
     'Twitter HTML': {
@@ -379,6 +421,7 @@ schemes = {
             'following_count': lambda x: x.get('legacy', {}).get('friends_count'),
             'location': lambda x: x.get('legacy', {}).get('location'),
             'favourites_count': lambda x: x.get('legacy', {}).get('favourites_count'),
+            'links': lambda x: [y.get('expanded_url') for y in x.get('legacy', {}).get('entities', {}).get('url', {}).get('urls', [])],
         }
     },
     'Facebook user profile': {
@@ -617,7 +660,7 @@ schemes = {
         'regex': r'({"url":".+?});',
         'extract_json': True,
         'fields': {
-            'uid': lambda x: x['steamid'],
+            'steam_id': lambda x: x['steamid'],
             'nickname': lambda x: x['personaname'],  # это не совсем имя, а ник
             'username': lambda x: [y for y in x['url'].split('/') if y][-1],
         }
@@ -873,6 +916,51 @@ schemes = {
             'social_links': lambda x: [y.get('url') for y in x['user']['social']],
         }
     },
+    'Linktree': {
+        'flags': ['content="Linktree. Make your link do more."'],
+        'regex': r'id="__NEXT_DATA__" type="application\/json" crossorigin="anonymous">(.+?)<\/script>',
+        'extract_json': True,
+        'transforms': [
+            json.loads,
+            lambda x: x['props']['pageProps'],
+            json.dumps,
+        ],
+        'fields': {
+            'id': lambda x: x.get('account', {}).get('id'),
+            'username': lambda x: x.get('username'),
+            'image': lambda x: x.get('profilePictureUrl'),
+            'is_active': lambda x: x.get('account', {}).get('isActive'),
+            'is_verified': lambda x: x.get('isProfileVerified'),
+            'facebook_pixel_id': lambda x: x.get('account', {}).get('facebookPixelId'),
+            'google_analytics_id': lambda x: x.get('account', {}).get('googleAnalyticsId'),
+            'is_email_verified': lambda x: x.get('account', {}).get('owner', {}).get('isEmailVerified'),
+            'bio': lambda x: x.get('description'),
+            'tier': lambda x: x.get('account', {}).get('tier'),
+            'links': lambda x: [y.get('url') for y in x.get('account', {}).get('links', [])] + x.get('socialLinks', []),
+        }
+    },
+    'Twitch': {
+        'flags': ['<meta property="al:android:url" content="twitch://'],
+        'regex': r'id="__NEXT_DATA__" type="application\/json">(.+?)<\/script>',
+        'extract_json': True,
+        'transforms': [
+            json.loads,
+            lambda x: x['props']['relayQueryRecords'],
+            lambda x: [v for k, v in x.items() if k.startswith('User') or k.endswith('followers')],
+            lambda x: dict(list(x[0].items()) + list(x[1].items())),
+            json.dumps,
+        ],
+        'fields': {
+            'id': lambda x: x.get('id').split('{')[-1],
+            'views_count': lambda x: x.get('profileViewCount'),
+            'username': lambda x: x.get('login'),
+            'bio': lambda x: x.get('description'),
+            'fullname': lambda x: x.get('displayName'),
+            'image': lambda x: x.get('profileImageURL(width:300)'),
+            'likes_count': lambda x: x.get('totalCount'),
+            'image_bg': lambda x: x.get('bannerImageURL'),
+        },
+    },
     'vBulletinEngine': {
         'flags': ['vBulletin.register_control'],
         'bs': True,
@@ -890,5 +978,48 @@ schemes = {
             'title': lambda x: x.find('div', {'class': 'title-group'}).find('span', {'class': 'description'}).text.strip(),
             'links': lambda x: [enrich_link(a.find('a').get('href')) for a in x.find('div', {'class': 'nav-wrapper'}).find_all('li', {'class': 'nav-item nav-item--page'})],
         }
-    }
+    },
+    '1x.com': {
+        'flags': ['content="https://www.1x.com/'],
+        'bs': True,
+        'fields': {
+            'fullname': lambda x: x.find('div', {'class': 'coveroverlay'}).find('td', {'valign': 'bottom'}).find('div').contents[0],
+            'image': lambda x:  'https://1x.com/' + x.find('img', {'class': 'member_profilepic'}).get('src', ''),
+        }
+    },
+    'Last.fm': {
+        'flags': ['Music Profile | Last.fm</title>'],
+        'bs': True,
+        'fields': {
+            'fullname': lambda x: x.find('span', {'class': 'header-title-display-name'}).contents[0].strip(),
+            # TODO: date convert
+            'bio': lambda x: x.find('span', {'class': 'header-scrobble-since'}).contents[0].strip(),
+            'image': lambda x: x.find('span', {'class': 'avatar'}).find('img').get('src', ''),
+        }
+    },
+    'Ask.fm': {
+        'flags': [' | ASKfm</title>'],
+        'bs': True,
+        'fields': {
+            'username': lambda x: x.find('span', {'class': 'userName_wrap'}).find('span', {'class': 'userName'}).contents[0].lstrip('@'),
+            'fullname': lambda x: x.find('h1', {'class': 'userName_status'}).find('span', {'class': 'userName'}).contents[0].lstrip('@'),
+            'posts_count': lambda x: x.find('div', {'class': 'profileStats_number profileTabAnswerCount'}).contents[0],
+            'likes_count': lambda x: x.find('div', {'class': 'profileStats_number profileTabLikeCount'}).contents[0],
+            'photo': lambda x: x.find('a', {'class': 'userAvatar-big'}).get('style').replace('background-image:url(','').rstrip(')'),
+            'location': lambda x: x.find('div', {'class': 'icon-location'}).contents[0],
+        }
+    },
+    'Launchpad': {
+        'flags': ['in Launchpad</title>'],
+        'bs': True,
+        'fields': {
+            'fullname': lambda x: x.find('h2', {'id': 'watermark-heading'}).find('a').contents[0],
+            'username': lambda x: x.find('dl', {'id': 'launchpad-id'}).find('dd').contents[0],
+            'languages': lambda x: x.find('dl', {'id': 'languages'}).find('dd').contents[0].strip(),
+            'karma': lambda x: x.find('a', {'id': 'karma-total'}).contents[0],
+            'created_at': lambda x: x.find('dd', {'id': 'member-since'}).contents[0],
+            'timezone': lambda x: re.sub(r'\s+', ' ', x.find('dl', {'id': 'timezone'}).find('dd').contents[0] or '').strip(),
+            'openpgp_key': lambda x: x.find('dl', {'id': 'pgp-keys'}).find('dd').contents[0].strip(),
+        },
+    },
 }
